You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by rn...@apache.org on 2019/10/03 18:14:49 UTC

[couchdb] 01/01: Ping clouseau directly

This is an automated email from the ASF dual-hosted git repository.

rnewson pushed a commit to branch ping-clouseau-directly
in repository https://gitbox.apache.org/repos/asf/couchdb.git

commit 2a430d6fcc3c9a59367cf0790cb30a32444fc484
Author: Robert Newson <rn...@apache.org>
AuthorDate: Thu Oct 3 19:13:33 2019 +0100

    Ping clouseau directly
    
    This change eliminates IOQ from the test path for clouseau
    connectivity.
---
 src/dreyfus/src/clouseau_rpc.erl | 9 ++-------
 1 file changed, 2 insertions(+), 7 deletions(-)

diff --git a/src/dreyfus/src/clouseau_rpc.erl b/src/dreyfus/src/clouseau_rpc.erl
index 38247ff..b8190b3 100644
--- a/src/dreyfus/src/clouseau_rpc.erl
+++ b/src/dreyfus/src/clouseau_rpc.erl
@@ -98,13 +98,8 @@ connected() ->
         true ->
             true;
         false ->
-            % We might have just booted up, so let's send a test RPC
-            case (catch version()) of
-                {ok, _} ->
-                    true;
-                _Err ->
-                    false
-            end
+            % We might have just booted up, so let's ping
+            pong == net_adm:ping(clouseau())
     end.
 
 rpc(Ref, Msg) ->